How to contribute
=================

Cartopy is driven by a community of people all passionate about
seeing cartopy flourish as a world class mapping package for Python.
This page lists the guidelines for contributors which
will help ease the process of getting your hard work accepted back into
the cartopy repository.


Getting started
---------------

1. If you've not already got one, sign up for a
   [GitHub account](https://github.com/signup/free).
1. Fork the Cartopy repository, create your new fix/feature branch, and
   start committing code. We broadly follow the [gitwash guidelines](https://matthew-brett.github.io/pydagogue/gitwash/git_development.html).
1. Remember to add appropriate documentation and tests to supplement any new or changed functionality.
1. If you're not already on it (and would like to be), please add yourself to the 
   contributors list (docs/source/contributors.rst)


Submitting changes
------------------

1. Read and sign the Contributor Licence Agreement (CLA) if you have not already done so.
    - See the [governance page](http://scitools.org.uk/governance.html)
      for the CLA and what to do with it.
1. Push your branch to your fork of cartopy.
1. Submit your pull request.
1. Sit back and wait for the core Cartopy development team to review your code.

